==> foundry_platform_sdk-0.84.0.tar.gz: foundry_platform_sdk-0.84.0/foundry/v2/admin/errors/_remove_marking_role_assignments_remove_all_administrators_not_allowed.py <==
#  Copyright 2024 Palantir Technologies, Inc.
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.


from __future__ import annotations

from dataclasses import dataclass
from typing import List
from typing import Literal

import pydantic
from typing_extensions import TypedDict

from foundry._errors import PalantirRPCException
from foundry.v2.core.models._marking_id import MarkingId
from foundry.v2.core.models._principal_id import PrincipalId


class RemoveMarkingRoleAssignmentsRemoveAllAdministratorsNotAllowedParameters(TypedDict):
    """You cannot remove all administrators from a marking."""

    __pydantic_config__ = {"extra": "allow"}  # type: ignore

    markingId: MarkingId

    currentAdministrators: List[PrincipalId]


@dataclass
class RemoveMarkingRoleAssignmentsRemoveAllAdministratorsNotAllowed(PalantirRPCException):
    name: Literal["RemoveMarkingRoleAssignmentsRemoveAllAdministratorsNotAllowed"]
    parameters: RemoveMarkingRoleAssignmentsRemoveAllAdministratorsNotAllowedParameters
    error_instance_id: str


__all__ = ["RemoveMarkingRoleAssignmentsRemoveAllAdministratorsNotAllowed"]

==> foundry_platform_sdk-0.95.0.tar.gz: foundry_platform_sdk-0.95.0/foundry/v2/admin/errors/_remove_marking_role_assignments_remove_all_administrators_not_allowed.py <==
#  Copyright 2024 Palantir Technologies, Inc.
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.


from __future__ import annotations

from dataclasses import dataclass
from typing import List
from typing import Literal

from typing_extensions import TypedDict

from foundry._errors import BadRequestError
from foundry.v2.core.models._marking_id import MarkingId
from foundry.v2.core.models._principal_id import PrincipalId


class RemoveMarkingRoleAssignmentsRemoveAllAdministratorsNotAllowedParameters(TypedDict):
    """You cannot remove all administrators from a marking."""

    __pydantic_config__ = {"extra": "allow"}  # type: ignore

    markingId: MarkingId

    currentAdministrators: List[PrincipalId]


@dataclass
class RemoveMarkingRoleAssignmentsRemoveAllAdministratorsNotAllowed(BadRequestError):
    name: Literal["RemoveMarkingRoleAssignmentsRemoveAllAdministratorsNotAllowed"]
    parameters: RemoveMarkingRoleAssignmentsRemoveAllAdministratorsNotAllowedParameters
    error_instance_id: str


__all__ = ["RemoveMarkingRoleAssignmentsRemoveAllAdministratorsNotAllowed"]
